@@ -23,9 +23,12 @@ we will get the statistics on drivers displayed on the screen in descending  ord
 we will get statistics displayed on the screen for a specific driver
 """
 import argparse
+import sqlite3
 from datetime import datetime
 from pathlib import Path
 
+from src.models import *
+
 ABBR_FILENAME = 'abbreviations.txt'
 START_FILENAME = 'start.log'
 END_FILENAME = 'end.log'
@@ -59,44 +62,71 @@ def parsed_start_end_lines(row_strings):
     return parsed_lines
 
 
-def build_report(dir_, desc=False):
-    """Construction report based on data from the directory.
-    
-    The function accepts the main directory parameter, and desc.
-    The directory parameter specifies the name of the directory where the 3 abbreviation files are stored,
-    the start time and the end time of the circle. After receiving this data, their processing begins,
-    first there is a directory and files in it, then they are parsed and sorted.
-    Next, the calculation of the lap time of each driver takes place,
+def create_database(dir_):
+    """
+     Create database and fill it.
+    """
+    try:
+        path_dir = Path(dir_).resolve()
+        drivers = parse_abbr_lines(read_file(path_dir / ABBR_FILENAME))
+        start_times = parsed_start_end_lines(read_file(path_dir / START_FILENAME))
+        end_times = parsed_start_end_lines(read_file(path_dir / END_FILENAME))
+        db = SqliteDatabase('database.db')
+        db.drop_tables([Driver, StartLog, EndLog])
+        with db.atomic() as transaction:
+            db.create_tables([Driver, StartLog, EndLog])
+            Driver.insert_many(drivers).execute()
+            StartLog.insert_many(start_times).execute()
+            EndLog.insert_many(end_times).execute()
+    except FileNotFoundError:
+        print(dir_, 'No such file or directory. Please, input the correct path')
+
+
+def get_data_from_db():
+    """
+    Get data from database.
+    Return list data.
+    List data have into: abbr, name, team, time, time_start, time_finish.
+    """
+    with sqlite3.connect('database.db') as db:
+        list_data = []
+        cursor = db.cursor()
+        query = """ SELECT abbr, name, team, time_start, time_finish FROM drivers
+                    JOIN start_logs ON start_logs.abbr_id = drivers.abbr
+                     JOIN end_logs ON end_logs.abbr_id = drivers.abbr"""
+        cursor.execute(query)
+        for data in cursor:
+            abbr = data[0]
+            name = data[1]
+            team = data[2]
+            time_start = datetime.strptime(data[3], '%H:%M:%S') if len(data[3]) < 9 \
+                else datetime.strptime(data[3], '%H:%M:%S.%f')
+            time_finish = datetime.strptime(data[4], '%H:%M:%S') if len(data[4]) < 9 \
+                else datetime.strptime(data[4], '%H:%M:%S.%f')
+            list_data.append((abbr, name, team, time_start, time_finish))
+        return list_data
+
+
+def build_report(data, desc=False):
+    """Construction report based on data.
+
+    The function accepts the data, and desc.
+    The calculation of the lap time of each driver takes place,
     if the data on the start and end times of the lap are mixed up,
-    the function will replace them with places. The function also finds the driver's full data by the abbreviation
-    and substitutes it instead of the abbreviation. As a result,
+    the function will replace them with places. As a result,
     we will get a list of drivers with the default lap time in ascending order,
     or if a parameter is specified desc=True, in descending order.
 
     """
-    try:
-        Path(dir_).resolve()
-    except FileNotFoundError:
-        print(dir_, 'No such file or directory. Please, input the correct path')
-    abbr_filepath = Path(dir_).resolve() / ABBR_FILENAME
-    start_filepath = Path(dir_).resolve() / START_FILENAME
-    end_filepath = Path(dir_).resolve() / END_FILENAME
-    abbr_lines = sorted(parse_abbr_lines(read_file(abbr_filepath)))
-    start_lines = dict(sorted(parsed_start_end_lines(read_file(start_filepath))))
-    end_lines = dict(sorted(parsed_start_end_lines(read_file(end_filepath))))
-
-    result = []
-    for abbr_item, (abbr_st, start_time), (abbr_en, end_time) in zip(abbr_lines, start_lines.items(),
-                                                                     end_lines.items()):
-        if abbr_st == abbr_en:
-            time_lap = str(end_time - start_time)
-            if start_time > end_time:
-                time_lap = str(start_time - end_time)
-        if abbr_st == abbr_item[0]:
-            abbr_st = abbr_item[1], abbr_item[2]
-            result.append((*abbr_st, time_lap, abbr_item[0]))
-            result.sort(key=lambda x: x[2])
-    return result if not desc else sorted(result, key=lambda x: x[2], reverse=True)
+    list_item = []
+    for item in data:
+        abbr = item[0]
+        name = item[1]
+        team = item[2]
+        time_lap = str(item[3] - item[4]) if item[3] > item[4] else str(item[4] - item[3])
+        list_item.append((abbr, name, team, time_lap))
+        list_item.sort(key=lambda x: x[3])
+    return list_item if not desc else sorted(list_item, key=lambda x: x[3], reverse=True)
 
 
 def print_report(data):
@@ -120,8 +150,9 @@ def find_driver(data, driver):
     """
     filterated_date = list(filter(lambda item: item[0] == driver, data)) \
                       or list(filter(lambda item: str("".join(e[0]
-                      for e in str(item[0]).split()) + "".join(e[0]
-                      for e in str(item[1]).split()))[0:3] == driver, data))
+                                                              for e in str(item[0]).split()) + "".join(e[0]
+                                                                                                       for e in str(
+        item[1]).split()))[0:3] == driver, data))
     if not filterated_date:
         raise NameError("Please, check the name of the pilot, enter a valid name. Example 'Sebastian Vettel' or 'SVF' ")
     return filterated_date[0]
@@ -134,7 +165,9 @@ def main():
     parser.add_argument('--driver', nargs='?', type=str, help='statistic about driver')
     parser.add_argument('--desc', default=False, action="store_true", help='list of drivers order is desc')
     args = parser.parse_args()
-    result = build_report(args.files, args.desc)
+    create_data = create_database(args.files)
+    data = get_data_from_db()
+    result = build_report(data, args.desc)
     if args.driver:
         print(find_driver(result, args.driver))
     else:
